#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# List of defaul languages, omitting country code should be okay
DEFAULT_LANGS = (
    "af_za",
    "am_et",
    "ar_aa",
    "as_in",
    "az_az",
    "be_by",
    "bg_bg",
    "bn_bd",
    "bo_bt",
    "br_fr",
    "bs_ba",
    "ca_es",
    "cs_cz",
    "cy_gb",
    "da_dk",
    "de_de",
    "ee_ee",
    "el_gr",
    "en_us",
    "eo_xx",
    "es_es",
    "et_ee",
    "eu_es",
    "fa_ir",
    "fi_fi",
    "fo_fo",
    "fr_fr",
    "ga_ie",
    "gd_gb",
    "gl_es",
    "gu_in",
    "gv_gb",
    "he_il",
    "hi_in",
    "hr_hr",
    "hu_hu",
    "hy_am",
    "id_id",
    "is_is",
    "it_it",
    "iu_ca",
    "ja_jp",
    "ka_ge",
    "kk_kz",
    "kl_gl",
    "km_kh",
    "kn_in",
    "ko_kr",
    "ks_in",
    "kw_gb",
    "ky_kg",
    "lb_lu",
    "lo_la",
    "lt_lt",
    "lv_lv",
    "mi_nz",
    "mk_mk",
    "ml_in",
    "mn_mn",
    "mr_in",
    "ms_my",
    "mt_mt",
    "my_mm",
    "ne_np",
    "nl_nl",
    "nn_no",
    "no_no",
    "nr_za",
    "ny_no",
    "oc_fr",
    "or_in",
    "pa_in",
    "pd_us",
    "ph_ph",
    "pl_pl",
    "pp_an",
    "pt_pt",
    "ro_ro",
    "ru_ru",
    "rw_rw",
    "sa_in",
    "sd_in",
    "si_lk",
    "sk_sk",
    "sl_si",
    "sq_al",
    "sr_rs",
    "ss_za",
    "st_za",
    "sv_se",
    "ta_in",
    "te_in",
    "tg_tj",
    "th_th",
    "tk_tm",
    "tl_ph",
    "tn_za",
    "tr_tr",
    "ts_za",
    "tt_ru",
    "uk_ua",
    "ur_pk",
    "uz_uz",
    "ve_za",
    "vi_vn",
    "wa_be",
    "xh_za",
    "yi_us",
    "zu_za",
    "ast_es",
    "gug_py",
)



#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


PLURAL_TAGS = {
    "af": ["one", "other"],
    "ak": ["one", "other"],
    "am": ["one", "other"],
    "an": ["one", "other"],
    "ar": ["zero", "one", "two", "few", "many", "other"],
    "ars": ["zero", "one", "two", "few", "many", "other"],
    "as": ["one", "other"],
    "asa": ["one", "other"],
    "ast": ["one", "other"],
    "az": ["one", "other"],
    "be": ["one", "few", "many"],
    "bem": ["one", "other"],
    "bez": ["one", "other"],
    "bg": ["one", "other"],
    "bho": ["one", "other"],
    "bm": ["other"],
    "bn": ["one", "other"],
    "bo": ["other"],
    "br": ["one", "two", "few", "many", "other"],
    "brx": ["one", "other"],
    "bs": ["one", "few", "other"],
    "ca": ["one", "other"],
    "ce": ["one", "other"],
    "ceb": ["one", "other"],
    "cgg": ["one", "other"],
    "chr": ["one", "other"],
    "ckb": ["one", "other"],
    "cs": ["one", "few", "other"],
    "cy": ["zero", "one", "two", "few", "many", "other"],
    "da": ["one", "other"],
    "de": ["one", "other"],
    "dsb": ["one", "two", "few", "other"],
    "dv": ["one", "other"],
    "dz": ["other"],
    "ee": ["one", "other"],
    "el": ["one", "other"],
    "en": ["one", "other"],
    "eo": ["one", "other"],
    "es": ["one", "other"],
    "et": ["one", "other"],
    "eu": ["one", "other"],
    "fa": ["one", "other"],
    "ff": ["one", "other"],
    "fi": ["one", "other"],
    "fil": ["one", "other"],
    "fo": ["one", "other"],
    "fr": ["one", "other"],
    "fur": ["one", "other"],
    "fy": ["one", "other"],
    "ga": ["one", "two", "few", "many", "other"],
    "gd": ["one", "two", "few", "other"],
    "gl": ["one", "other"],
    "gsw": ["one", "other"],
    "gu": ["one", "other"],
    "guw": ["one", "other"],
    "gv": ["one", "two", "few", "other"],
    "ha": ["one", "other"],
    "haw": ["one", "other"],
    "he": ["one", "two", "many", "other"],
    "hi": ["one", "other"],
    "hr": ["one", "few", "other"],
    "hsb": ["one", "two", "few", "other"],
    "hu": ["one", "other"],
    "hy": ["one", "other"],
    "ia": ["one", "other"],
    "id": ["other"],
    "ig": ["other"],
    "ii": ["other"],
    "in": ["other"],
    "io": ["one", "other"],
    "is": ["one", "other"],
    "it": ["one", "other"],
    "iu": ["one", "two", "other"],
    "iw": ["one", "two", "many", "other"],
    "ja": ["other"],
    "jbo": ["other"],
    "jgo": ["one", "other"],
    "ji": ["one", "other"],
    "jmc": ["one", "other"],
    "jv": ["other"],
    "jw": ["other"],
    "ka": ["one", "other"],
    "kab": ["one", "other"],
    "kaj": ["one", "other"],
    "kcg": ["one", "other"],
    "kde": ["other"],
    "kea": ["other"],
    "kk": ["one", "other"],
    "kkj": ["one", "other"],
    "kl": ["one", "other"],
    "km": ["other"],
    "kn": ["one", "other"],
    "ko": ["other"],
    "ks": ["one", "other"],
    "ksb": ["one", "other"],
    "ksh": ["zero", "one", "other"],
    "ku": ["one", "other"],
    "kw": ["zero", "one", "two", "few", "many", "other"],
    "ky": ["one", "other"],
    "lag": ["zero", "one", "other"],
    "lb": ["one", "other"],
    "lg": ["one", "other"],
    "lkt": ["other"],
    "ln": ["one", "other"],
    "lo": ["other"],
    "lt": ["one", "few", "other"],
    "lv": ["zero", "one", "other"],
    "mas": ["one", "other"],
    "mg": ["one", "other"],
    "mgo": ["one", "other"],
    "mk": ["one", "other"],
    "ml": ["one", "other"],
    "mn": ["one", "other"],
    "mo": ["one", "few", "other"],
    "mr": ["one", "other"],
    "ms": ["other"],
    "mt": ["one", "few", "many", "other"],
    "my": ["other"],
    "nah": ["one", "other"],
    "naq": ["one", "two", "other"],
    "nb": ["one", "other"],
    "nd": ["one", "other"],
    "ne": ["one", "other"],
    "nl": ["one", "other"],
    "nn": ["one", "other"],
    "nnh": ["one", "other"],
    "no": ["one", "other"],
    "nqo": ["other"],
    "nr": ["one", "other"],
    "nso": ["one", "other"],
    "ny": ["one", "other"],
    "nyn": ["one", "other"],
    "om": ["one", "other"],
    "or": ["one", "other"],
    "os": ["one", "other"],
    "osa": ["other"],
    "pa": ["one", "other"],
    "pap": ["one", "other"],
    "pcm": ["one", "other"],
    "pl": ["one", "few", "many"],
    "prg": ["zero", "one", "other"],
    "ps": ["one", "other"],
    "pt": ["one", "other"],
    "pt-PT": ["one", "other"],
    "rm": ["one", "other"],
    "ro": ["one", "few", "other"],
    "rof": ["one", "other"],
    "root": ["other"],
    "ru": ["one", "few", "many"],
    "rwk": ["one", "other"],
    "sah": ["other"],
    "saq": ["one", "other"],
    "sat": ["one", "two", "other"],
    "sc": ["one", "other"],
    "scn": ["one", "other"],
    "sd": ["one", "other"],
    "sdh": ["one", "other"],
    "se": ["one", "two", "other"],
    "seh": ["one", "other"],
    "ses": ["other"],
    "sg": ["other"],
    "sh": ["one", "few", "other"],
    "shi": ["one", "few", "other"],
    "si": ["one", "other"],
    "sk": ["one", "few", "other"],
    "sl": ["one", "two", "few", "other"],
    "sma": ["one", "two", "other"],
    "smi": ["one", "two", "other"],
    "smj": ["one", "two", "other"],
    "smn": ["one", "two", "other"],
    "sms": ["one", "two", "other"],
    "sn": ["one", "other"],
    "so": ["one", "other"],
    "sq": ["one", "other"],
    "sr": ["one", "few", "other"],
    "ss": ["one", "other"],
    "ssy": ["one", "other"],
    "st": ["one", "other"],
    "su": ["other"],
    "sv": ["one", "other"],
    "sw": ["one", "other"],
    "syr": ["one", "other"],
    "ta": ["one", "other"],
    "te": ["one", "other"],
    "teo": ["one", "other"],
    "th": ["other"],
    "ti": ["one", "other"],
    "tig": ["one", "other"],
    "tk": ["one", "other"],
    "tl": ["one", "other"],
    "tn": ["one", "other"],
    "to": ["other"],
    "tr": ["one", "other"],
    "ts": ["one", "other"],
    "tzm": ["one", "other"],
    "ug": ["one", "other"],
    "uk": ["one", "few", "many"],
    "ur": ["one", "other"],
    "uz": ["one", "other"],
    "ve": ["one", "other"],
    "vi": ["other"],
    "vo": ["one", "other"],
    "vun": ["one", "other"],
    "wa": ["one", "other"],
    "wae": ["one", "other"],
    "wo": ["other"],
    "xh": ["one", "other"],
    "xog": ["one", "other"],
    "yi": ["one", "other"],
    "yo": ["other"],
    "yue": ["other"],
    "zh": ["other"],
    "zu": ["one", "other"],
}
